import random

from armstrong.dev.tests.utils import ArmstrongTestCase

from .related_content_support.models import Article


def generate_fake_articles(n):
    ret = []
    for i in range(n):
        article = Article.objects.create(
            title="Some Random Article %d" % random.randint(1000, 2000)
        )
        ret.append(article)
    return ret


class TestCase(ArmstrongTestCase):
    pass



import datetime
import os
from django.template import Context, NodeList, RequestContext, Template,\
                            TemplateDoesNotExist, Variable
from django.core.files import File
from ._utils import TestCase
from .related_content_support.models import Article, Image
from ..models import RelatedType, RelatedContent


class lead_artTestCase(TestCase):
    def setUp(self):
        self.obj = Article.objects.create(title='foo')
        lead_art, created = RelatedType.objects.get_or_create(title='lead_art')
        path = os.path.split(__file__)[0]
        img = Image.objects.create(title='image')
        RelatedContent.objects.create(destination_object=img,
                                      source_object=self.obj,
                                      related_type=lead_art)

    def render(self, string):
        template = Template(string)
        ctx = {'obj': self.obj}
        return template.render(Context(ctx))

    def testLargeSize(self):
        large_string = "{% load related_content %}{% lead_art obj 'large' %}"
        small_string = "{% load related_content %}{% lead_art obj 'small' %}"
        large_rendered = self.render(large_string)
        small_rendered = self.render(small_string)
        self.assertEqual(large_rendered, 'Render: large')
        self.assertEqual(small_rendered, 'Render: small')



from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes.generic import GenericForeignKey
from django.db import models
from ._utils import *
from django import template

from ..models import RelatedContent
from ..models import RelatedType

from .models import generate_model

class RelatedContentFieldTestCase(TestCase):
    def test_related_contains_all_related_models(self):
        one, two, c = generate_model()
        related_content = one.related_content.all()
        self.assertEqual(1, related_content.count())
        self.assertEqual(related_content[0].destination_object, two)


class RelatedObjectsFieldTestCase(TestCase):
    def test_contains_all_related_objects_for_given_source(self):
        one, two, c = generate_model()
        related_content = one.related.all()
        self.assertEqual(1, related_content.count())
        self.assertEqual(related_content[0], two)

    def test_filtering_by_type(self):
        one, two, c = generate_model()
        related_content = one.related.by_type(c.related_type.title)
        self.assertEqual(1, related_content.count())
        self.assertEqual(related_content[0], two)

    def test_filtering_by_getitem(self):
        one, two, c = generate_model()
        related_content = one.related[c.related_type.title]
        self.assertEqual(1, related_content.count())
        self.assertEqual(related_content[0], two)

    def test_filtering_by_type_with_no_results(self):
        one, two, c = generate_model()
        related_content = one.related.by_type("invalid_type")
        self.assertEqual(0, related_content.count())

    def test_template_filtering(self):
        one, two, c = generate_model()
        c.related_type.title = "type_title"
        c.related_type.save()
        t = template.Template("{{ one.related.type_title.0.title }}")
        result = t.render(template.Context(locals()))
        self.assertEqual(result, two.title)


class ReverseRelatedObjectsFieldTestCase(TestCase):
    def test_contains_all_related_objects_for_given_source(self):
        one, two, c = generate_model()
        related_content = two.reverse_related.all()
        self.assertEqual(1, related_content.count())
        self.assertEqual(related_content[0], one)
